@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -698,6 +698,62 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeSafeAuthFlagIntl(self, request):
+        """查询安全设置(国际站)
+
+        :param request: Request instance for DescribeSafeAuthFlagIntl.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeSafeAuthFlagIntlRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeSafeAuthFlagIntlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSafeAuthFlagIntl", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSafeAuthFlagIntlResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeSubAccounts(self, request):
+        """通过子用户UIN列表查询子用户
+
+        :param request: Request instance for DescribeSubAccounts.
+        :type request: :class:`tencentcloud.cam.v20190116.models.DescribeSubAccountsRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.DescribeSubAccountsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeSubAccounts", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeSubAccountsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DetachGroupPolicy(self, request):
         """本接口（DetachGroupPolicy）可用于解除绑定到用户组的策略。
 
@@ -782,6 +838,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetAccountSummary(self, request):
+        """查询账户摘要
+
+        :param request: Request instance for GetAccountSummary.
+        :type request: :class:`tencentcloud.cam.v20190116.models.GetAccountSummaryRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.GetAccountSummaryResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetAccountSummary", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetAccountSummaryResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetCustomMFATokenInfo(self, request):
         """获取自定义多因子Token关联信息
 
@@ -950,6 +1034,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GetSecurityLastUsed(self, request):
+        """获取密钥最近使用情况
+
+        :param request: Request instance for GetSecurityLastUsed.
+        :type request: :class:`tencentcloud.cam.v20190116.models.GetSecurityLastUsedRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.GetSecurityLastUsedResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetSecurityLastUsed", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetSecurityLastUsedResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetServiceLinkedRoleDeletionStatus(self, request):
         """根据删除TaskId获取服务相关角色删除状态
 
@@ -1258,6 +1370,34 @@ class CamClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListPoliciesGrantingServiceAccess(self, request):
+        """获取所有已授权服务
+
+        :param request: Request instance for ListPoliciesGrantingServiceAccess.
+        :type request: :class:`tencentcloud.cam.v20190116.models.ListPoliciesGrantingServiceAccessRequest`
+        :rtype: :class:`tencentcloud.cam.v20190116.models.ListPoliciesGrantingServiceAccessResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListPoliciesGrantingServiceAccess", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListPoliciesGrantingServiceAccessResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListPolicyVersions(self, request):
         """该接口（ListPolicyVersions）用于获取策略版本列表
 
